"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ScriptBuilders_1 = require("./ScriptBuilders");
let log = null;
function activate(context) {
    log = context.logger;
    context.workspace.registerCommandsOnTerminal(terminalCommandLister, terminalCommandExecutor);
}
exports.activate = activate;
const COMMAND_INJECT_BASH_INTEGRATION = "injectBashIntegration";
const COMMAND_INJECT_FISH_INTEGRATION = "injectFishIntegration";
const COMMAND_INJECT_ZSH_INTEGRATION = "injectZshIntegration";
function terminalCommandLister(terminal) {
    return [{
            id: COMMAND_INJECT_BASH_INTEGRATION,
            label: "Inject Bash Shell Integration"
        },
        {
            id: COMMAND_INJECT_FISH_INTEGRATION,
            label: "Inject Fish Shell Integration"
        },
        {
            id: COMMAND_INJECT_ZSH_INTEGRATION,
            label: "Inject Zsh Shell Integration"
        }];
}
function terminalCommandExecutor(terminal, commandId, commandArguments) {
    return __awaiter(this, void 0, void 0, function* () {
        const scriptCommands = getScriptCommands(terminal, commandId);
        executeScriptCommands(terminal, scriptCommands);
    });
}
function getScriptCommands(terminal, commandId) {
    switch (commandId) {
        case COMMAND_INJECT_BASH_INTEGRATION:
            return new ScriptBuilders_1.BashScriptBuilder(terminal.getExtratermCookieName(), terminal.getExtratermCookieValue()).build();
        case COMMAND_INJECT_FISH_INTEGRATION:
            return new ScriptBuilders_1.FishScriptBuilder(terminal.getExtratermCookieName(), terminal.getExtratermCookieValue()).build();
        case COMMAND_INJECT_ZSH_INTEGRATION:
            return new ScriptBuilders_1.ZshScriptBuilder(terminal.getExtratermCookieName(), terminal.getExtratermCookieValue()).build();
        default:
            return [];
    }
}
function executeScriptCommands(terminal, scriptCommands) {
    return __awaiter(this, void 0, void 0, function* () {
        for (const command of scriptCommands) {
            if (command.type === 'text') {
                terminal.type(normalizeCarriageReturns(command.text));
            }
            else {
                yield sleepMilliseconds(command.durationMilliseconds);
            }
        }
    });
}
function normalizeCarriageReturns(text) {
    return text.replace(/\n/g, '\r');
}
function sleepMilliseconds(durationMilliseconds) {
    return new Promise((resolve) => {
        setTimeout(resolve, durationMilliseconds);
    });
}
//# sourceMappingURL=InjectShellIntegrationExtension.js.map