"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
let extensionContext = null;
function activate(context) {
    extensionContext = context;
    context.workspace.registerCommandsOnTextViewer(textViewerCommandLister, textViewerCommandExecutor);
}
exports.activate = activate;
const COMMAND_SET_SYNTAX_HIGHLIGHTING = "setSyntaxHighlighting";
function textViewerCommandLister(textViewer) {
    return [{
            id: COMMAND_SET_SYNTAX_HIGHLIGHTING,
            label: "Syntax: " + getMimeTypeName(textViewer)
        }];
}
function getMimeTypeName(textViewer) {
    const mimeType = textViewer.getMimeType();
    const matchingMimeList = extensionContext.codeMirrorModule.modeInfo.filter(info => info.mime === mimeType);
    return matchingMimeList.length !== 0 ? matchingMimeList[0].name : mimeType;
}
function textViewerCommandExecutor(textViewer, commandId, commandArguments) {
    return __awaiter(this, void 0, void 0, function* () {
        const mimeList = extensionContext.codeMirrorModule.modeInfo;
        sortArrayBy(mimeList, item => item.name.toLowerCase());
        const items = mimeList.map(item => item.name + ' ' + item.mime);
        const mimeTypeNames = mimeList.map(item => item.name);
        const selectedItemIndex = mimeTypeNames.indexOf(getMimeTypeName(textViewer));
        const newSelectedItemIndex = yield textViewer.getTab().showListPicker({
            title: "Syntax Highlighting",
            items: items,
            selectedItemIndex
        });
        if (newSelectedItemIndex !== undefined) {
            textViewer.setMimeType(mimeList[newSelectedItemIndex].mime);
        }
    });
}
function sortArrayBy(items, keyFunc) {
    items.sort((a, b) => {
        const keyA = keyFunc(a);
        const keyB = keyFunc(b);
        if (keyA === keyB) {
            return 0;
        }
        return keyA < keyB ? -1 : 1;
    });
}
//# sourceMappingURL=TextViewerSyntaxHighlightingExtension.js.map