/*
 * Copyright 2014-2016 Simon Edwards <simon@simonzone.com>
 *
 * This source code is licensed under the MIT license which is detailed in the LICENSE.txt file.
 */
// About tab
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ThemeTypes = require("./Theme");
const ViewerElement_1 = require("./ViewerElement");
const ThemeableElementBase_1 = require("./ThemeableElementBase");
const DomUtils = require("./DomUtils");
const electron_1 = require("electron");
const Logger_1 = require("./Logger");
const ID_ABOUT = "ID_ABOUT";
let registered = false;
/**
 * The Extraterm About tab.
 */
class AboutTab extends ViewerElement_1.ViewerElement {
    //-----------------------------------------------------------------------
    //
    //   #                                                         
    //   #       # ###### ######  ####  #   #  ####  #      ###### 
    //   #       # #      #      #    #  # #  #    # #      #      
    //   #       # #####  #####  #        #   #      #      #####  
    //   #       # #      #      #        #   #      #      #      
    //   #       # #      #      #    #   #   #    # #      #      
    //   ####### # #      ######  ####    #    ####  ###### ###### 
    //
    //-----------------------------------------------------------------------
    constructor() {
        super();
        this._initProperties();
    }
    /**
     * Initialize the EtAboutTab class and resources.
     *
     * When EtAboutTab is imported into a render process, this static method
     * must be called before an instances may be created. This is can be safely
     * called multiple times.
     */
    static init() {
        if (registered === false) {
            window.customElements.define(AboutTab.TAG_NAME.toLowerCase(), AboutTab);
            registered = true;
        }
    }
    _initProperties() {
        this._log = Logger_1.getLogger(AboutTab.TAG_NAME, this);
    }
    //-----------------------------------------------------------------------
    //
    // ######                                
    // #     # #    # #####  #      #  ####  
    // #     # #    # #    # #      # #    # 
    // ######  #    # #####  #      # #      
    // #       #    # #    # #      # #      
    // #       #    # #    # #      # #    # 
    // #        ####  #####  ###### #  ####  
    //
    //-----------------------------------------------------------------------
    getAwesomeIcon() {
        return "lightbulb-o";
    }
    getTitle() {
        return "About";
    }
    focus() {
        // util.getShadowId(this, ID_CONTAINER).focus();
    }
    hasFocus() {
        return false;
    }
    /**
     * Custom Element 'connected' life cycle hook.
     */
    connectedCallback() {
        super.connectedCallback();
        if (DomUtils.getShadowRoot(this) == null) {
            const shadow = this.attachShadow({ mode: 'open', delegatesFocus: true });
            const themeStyle = document.createElement('style');
            themeStyle.id = ThemeableElementBase_1.ThemeableElementBase.ID_THEME;
            const divContainer = document.createElement('div');
            divContainer.innerHTML = `<div id='${ID_ABOUT}'>
  <h1>Extraterm</h1>
  <p>Copyright &copy; 2015-2017 Simon Edwards &lt;simon@simonzone.com&gt;</p>
  <p>Published under the MIT license</p>
  <p>See <a href="http://extraterm.org">extraterm.org</a> and <a href="https://github.com/sedwards2009/extraterm">https://github.com/sedwards2009/extraterm</a></p>
  <hr>
  <p>Extraterm logos were designed and provided by <a href="https://github.com/g-harel">Gabriel Harel (https://github.com/g-harel)</a>.</p>
  <p>This software uses EmojiOne for color emoji under the Creative Commons Attribution 4.0 International (CC BY 4.0) license. <a href="http://emojione.com">http://emojione.com</a></p>
</div>
`;
            shadow.appendChild(themeStyle);
            shadow.appendChild(divContainer);
            divContainer.addEventListener('click', this._handleClick.bind(this));
            this.updateThemeCss();
        }
    }
    _handleClick(ev) {
        ev.preventDefault();
        if (ev.target.tagName === "A") {
            const href = ev.target.href;
            electron_1.shell.openExternal(href);
        }
    }
    _themeCssFiles() {
        return [ThemeTypes.CssFile.GUI_CONTROLS, ThemeTypes.CssFile.ABOUT_TAB];
    }
}
/**
 * The HTML tag name of this element.
 */
AboutTab.TAG_NAME = "ET-ABOUT-TAB";
exports.AboutTab = AboutTab;
//# sourceMappingURL=AboutTab.js.map