/*
 * Copyright 2017 Simon Edwards <simon@simonzone.com>
 *
 * This source code is licensed under the MIT license which is detailed in the LICENSE.txt file.
 */
// Empty Pane Menu tab
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ThemeTypes = require("./Theme");
const ThemeableElementBase_1 = require("./ThemeableElementBase");
const ListPicker_1 = require("./gui/ListPicker");
const DomUtils = require("./DomUtils");
const CommandPaletteFunctions_1 = require("./CommandPaletteFunctions");
const Logger_1 = require("./Logger");
const ID_EMPTY_PANE_MENU = "ID_EMPTY_PANE_MENU";
const ID_LIST_PICKER = "ID_LIST_PICKER";
const ID_CONTAINER = "ID_CONTAINER";
const ID_TITLE = "ID_TITLE";
let registered = false;
ListPicker_1.ListPicker.init();
/**
 * The Extraterm Empty Pane Menu.
 */
class EmptyPaneMenu extends ThemeableElementBase_1.ThemeableElementBase {
    //-----------------------------------------------------------------------
    //
    //   #                                                         
    //   #       # ###### ######  ####  #   #  ####  #      ###### 
    //   #       # #      #      #    #  # #  #    # #      #      
    //   #       # #####  #####  #        #   #      #      #####  
    //   #       # #      #      #        #   #      #      #      
    //   #       # #      #      #    #   #   #    # #      #      
    //   ####### # #      ######  ####    #    ####  ###### ###### 
    //
    //-----------------------------------------------------------------------
    constructor() {
        super();
        this._initProperties();
    }
    /**
     * Initialize the EmptyPaneMenu class and resources.
     *
     * When EmptyPaneMenu is imported into a render process, this static method
     * must be called before an instances may be created. This is can be safely
     * called multiple times.
     */
    static init() {
        if (registered === false) {
            window.customElements.define(EmptyPaneMenu.TAG_NAME.toLowerCase(), EmptyPaneMenu);
            registered = true;
        }
    }
    _initProperties() {
        this._log = Logger_1.getLogger(EmptyPaneMenu.TAG_NAME, this);
        this._entries = [];
        this._selectedId = null;
    }
    //-----------------------------------------------------------------------
    //
    // ######                                
    // #     # #    # #####  #      #  ####  
    // #     # #    # #    # #      # #    # 
    // ######  #    # #####  #      # #      
    // #       #    # #    # #      # #      
    // #       #    # #    # #      # #    # 
    // #        ####  #####  ###### #  ####  
    //
    //-----------------------------------------------------------------------
    focus() {
        const listPicker = DomUtils.getShadowId(this, ID_LIST_PICKER);
        if (listPicker != null) {
            listPicker.focus();
        }
    }
    hasFocus() {
        return false;
    }
    setEntries(entries) {
        this._entries = entries;
        this._selectedId = null;
        if (DomUtils.getShadowRoot(this) != null) {
            const listPicker = DomUtils.getShadowId(this, ID_LIST_PICKER);
            listPicker.setEntries(entries);
        }
    }
    getEntries() {
        return this._entries;
    }
    getFilter() {
        const listPicker = DomUtils.getShadowId(this, ID_LIST_PICKER);
        return listPicker.getFilter();
    }
    setFilter(text) {
        const listPicker = DomUtils.getShadowId(this, ID_LIST_PICKER);
        listPicker.setFilter(text);
    }
    /**
     * Custom Element 'connected' life cycle hook.
     */
    connectedCallback() {
        super.connectedCallback();
        if (DomUtils.getShadowRoot(this) == null) {
            const shadow = this.attachShadow({ mode: 'open', delegatesFocus: true });
            const themeStyle = document.createElement('style');
            themeStyle.id = ThemeableElementBase_1.ThemeableElementBase.ID_THEME;
            const divContainer = document.createElement('div');
            divContainer.id = ID_EMPTY_PANE_MENU;
            divContainer.innerHTML = `<div id="${ID_CONTAINER}">
        <div id="${ID_TITLE}">Pane Menu</div>
        <${ListPicker_1.ListPicker.TAG_NAME} id="${ID_LIST_PICKER}"></${ListPicker_1.ListPicker.TAG_NAME}>
      </div>
  `;
            shadow.appendChild(themeStyle);
            shadow.appendChild(divContainer);
            const listPicker = DomUtils.getShadowId(this, ID_LIST_PICKER);
            listPicker.addEventListener("selected", (ev) => {
                const event = new CustomEvent("selected", { detail: { selected: ev.detail.selected } });
                this.dispatchEvent(event);
            });
            listPicker.setFilterAndRankEntriesFunc(CommandPaletteFunctions_1.commandPaletteFilterEntries);
            listPicker.setFormatEntriesFunc(CommandPaletteFunctions_1.commandPaletteFormatEntries);
            listPicker.addExtraCss([ThemeTypes.CssFile.GUI_COMMANDPALETTE]);
            listPicker.setEntries(this._entries);
            this.updateThemeCss();
        }
    }
    _themeCssFiles() {
        return [ThemeTypes.CssFile.GUI_CONTROLS, ThemeTypes.CssFile.EMPTY_PANE_MENU];
    }
}
/**
 * The HTML tag name of this element.
 */
EmptyPaneMenu.TAG_NAME = "ET-EMPTY-PANE-MENU";
exports.EmptyPaneMenu = EmptyPaneMenu;
//# sourceMappingURL=EmptyPaneMenu.js.map