"use strict";
/*
 * Copyright 2016 Simon Edwards <simon@simonzone.com>
 *
 * This source code is licensed under the MIT license which is detailed in the LICENSE.txt file.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const SourceMapSupport = require("source-map-support");
const fs = require("fs");
const path = require("path");
const MimeTypeDetector = require("./MimeTypeDetector");
SourceMapSupport.install();
function readTestFile(filename) {
    const fullPath = path.join('src', 'testfiles', filename);
    return fs.readFileSync(fullPath);
}
function testPng(test) {
    const result = MimeTypeDetector.detect(null, readTestFile("1x1.png"));
    test.notEqual(result, null);
    test.equal("image/png", result.mimeType);
    test.done();
}
exports.testPng = testPng;
function testGif(test) {
    const result = MimeTypeDetector.detect(null, readTestFile("blank.gif"));
    test.notEqual(result, null);
    test.equal("image/gif", result.mimeType);
    test.done();
}
exports.testGif = testGif;
function testBmp(test) {
    const result = MimeTypeDetector.detect(null, readTestFile("blank.bmp"));
    test.notEqual(result, null);
    test.equal("image/bmp", result.mimeType);
    test.done();
}
exports.testBmp = testBmp;
function testJpeg(test) {
    const result = MimeTypeDetector.detect(null, readTestFile("blank.jpg"));
    test.notEqual(result, null);
    test.equal("image/jpeg", result.mimeType);
    test.done();
}
exports.testJpeg = testJpeg;
function testWebp(test) {
    const result = MimeTypeDetector.detect(null, readTestFile("blank.webp"));
    test.notEqual(result, null);
    test.equal("image/webp", result.mimeType);
    test.done();
}
exports.testWebp = testWebp;
function testASCII(test) {
    const result = MimeTypeDetector.detect(null, readTestFile("ascii.txt"));
    test.notEqual(result, null);
    test.equal("text/plain", result.mimeType);
    test.done();
}
exports.testASCII = testASCII;
// Random binary data.
function testRandom(test) {
    const result = MimeTypeDetector.detect(null, readTestFile("random.bin"));
    test.notEqual(result, null);
    test.equal("application/octet-stream", result.mimeType);
    test.done();
}
exports.testRandom = testRandom;
// Part of a linux lib.so file.
function testLibSo(test) {
    const result = MimeTypeDetector.detect(null, readTestFile("libso.bin"));
    test.notEqual(result, null);
    test.equal("application/octet-stream", result.mimeType);
    test.done();
}
exports.testLibSo = testLibSo;
//# sourceMappingURL=MimeTypeDetectorTest.js.map