"use strict";
/*
 * Copyright 2014-2016 Simon Edwards <simon@simonzone.com>
 *
 * This source code is licensed under the MIT license which is detailed in the LICENSE.txt file.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const pty = require("ptyw.js");
class DirectPty {
    constructor(file, args, opt) {
        this._onDataCallback = null;
        this._permittedDataSize = 0;
        this._paused = true;
        this.realPty = pty.createTerminal(file, args, opt);
        this.realPty.on('data', (data) => {
            if (this._onDataCallback != null) {
                this._onDataCallback(data);
            }
            this.permittedDataSize(this._permittedDataSize - data.length);
        });
        this.realPty.pause();
    }
    write(data) {
        this.realPty.write(data);
    }
    resize(cols, rows) {
        this.realPty.resize(cols, rows);
    }
    onData(callback) {
        this._onDataCallback = callback;
    }
    onExit(callback) {
        this.realPty.on('exit', callback);
    }
    destroy() {
        this.realPty.destroy();
    }
    permittedDataSize(size) {
        this._permittedDataSize = size;
        if (size > 0) {
            if (this._paused) {
                this.realPty.resume();
                this._paused = false;
            }
        }
        else {
            if (!this._paused) {
                this.realPty.pause();
                this._paused = true;
            }
        }
    }
}
function spawn(file, args, opt) {
    return new DirectPty(file, args, opt);
}
function factory(config) {
    return {
        spawn: spawn,
        destroy() { }
    };
}
exports.factory = factory;
//# sourceMappingURL=PtyDirect.js.map