"use strict";
/*
 * Copyright 2017 Simon Edwards <simon@simonzone.com>
 *
 * This source code is licensed under the MIT license which is detailed in the LICENSE.txt file.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const Term_1 = require("./Term");
const performanceNow = require('performance-now');
function testBasic(test) {
    return __awaiter(this, void 0, void 0, function* () {
        const emulator = new Term_1.Emulator({ performanceNowFunc: performanceNow });
        emulator.write('Hello');
        yield waitOnEmulator(emulator);
        test.equals(emulator.getLineText(0).trim(), 'Hello');
        test.done();
    });
}
exports.testBasic = testBasic;
function testWrap(test) {
    return __awaiter(this, void 0, void 0, function* () {
        const emulator = new Term_1.Emulator({ rows: 10, columns: 20, performanceNowFunc: performanceNow });
        emulator.write('abcdefghijklmnopqrstuvwxyz');
        yield waitOnEmulator(emulator);
        test.equals(emulator.getLineText(0).trim(), 'abcdefghijklmnopqrst');
        test.equals(emulator.getLineText(1).trim(), 'uvwxyz');
        test.done();
    });
}
exports.testWrap = testWrap;
function testScrollOne(test) {
    return __awaiter(this, void 0, void 0, function* () {
        const emulator = new Term_1.Emulator({ rows: 10, columns: 20, performanceNowFunc: performanceNow });
        emulator.write('1\n');
        emulator.write('2\n');
        emulator.write('3\n');
        emulator.write('4\n');
        emulator.write('5\n');
        emulator.write('6\n');
        emulator.write('7\n');
        emulator.write('8\n');
        emulator.write('9\n');
        emulator.write('10\n');
        emulator.write('11');
        yield waitOnEmulator(emulator);
        test.equals(emulator.getLineText(0).trim(), '2');
        test.done();
    });
}
exports.testScrollOne = testScrollOne;
function testRenderDevice(test) {
    return __awaiter(this, void 0, void 0, function* () {
        const emulator = new Term_1.Emulator({ rows: 10, columns: 20, performanceNowFunc: performanceNow });
        const device = new RenderDevice();
        emulator.addRenderEventListener(device.renderEventListener.bind(device));
        emulator.write('1\r\n');
        emulator.write('2\r\n');
        emulator.write('3\r\n');
        emulator.write('4\r\n');
        emulator.write('5\r\n');
        emulator.write('6\r\n');
        emulator.write('7\r\n');
        emulator.write('8\r\n');
        emulator.write('9\r\n');
        emulator.write('10');
        yield waitOnEmulator(emulator);
        test.equals(readEmulatorScreenString(emulator), device.getScreenString());
        test.done();
    });
}
exports.testRenderDevice = testRenderDevice;
function testMoveCursor(test) {
    return __awaiter(this, void 0, void 0, function* () {
        const emulator = new Term_1.Emulator({ rows: 10, columns: 20, performanceNowFunc: performanceNow });
        const device = new RenderDevice();
        emulator.addRenderEventListener(device.renderEventListener.bind(device));
        emulator.write('1\r\n');
        emulator.write('2\r\n');
        emulator.write('3\r\n');
        emulator.write('4\r\n');
        emulator.write('5\r\n');
        emulator.write('6\r\n');
        emulator.write('7\r\n');
        emulator.write('8\r\n');
        emulator.write('9\r\n');
        emulator.write('10');
        emulator.write('\x1b[5;1H');
        yield waitOnEmulator(emulator);
        test.equals(lineToString(emulator.lineAtRow(4)).trim(), '#');
        test.done();
    });
}
exports.testMoveCursor = testMoveCursor;
function testMoveRowsAboveCursorToScrollback(test) {
    return __awaiter(this, void 0, void 0, function* () {
        const emulator = new Term_1.Emulator({ rows: 10, columns: 20, performanceNowFunc: performanceNow });
        const device = new RenderDevice();
        emulator.addRenderEventListener(device.renderEventListener.bind(device));
        emulator.write('1\r\n');
        emulator.write('2\r\n');
        emulator.write('3\r\n');
        emulator.write('4\r\n');
        emulator.write('5\r\n');
        emulator.write('6\r\n');
        emulator.write('7\r\n');
        emulator.write('8\r\n');
        emulator.write('9\r\n');
        emulator.write('10');
        emulator.write('\x1b[5;1H');
        yield waitOnEmulator(emulator);
        emulator.moveRowsAboveCursorToScrollback();
        yield waitOnEmulator(emulator);
        // console.log("Emulator");
        // console.log(`x: ${emulator.x}, y: ${emulator.y}`);
        // console.log(formatRectString(readEmulatorScreenString(emulator)));
        // console.log("Device");
        // console.log(formatRectString(device.getScrollbackString()));
        // console.log(formatRectString(device.getScreenString()));
        // test.equals(lineToString(emulator.lineAtRow(4)).trim(), '#');
        test.done();
    });
}
exports.testMoveRowsAboveCursorToScrollback = testMoveRowsAboveCursorToScrollback;
function waitOnEmulator(emulator) {
    return new Promise((resolve) => {
        setTimeout(resolve, 200);
    });
}
function readEmulatorScreenString(emulator) {
    let result = lineToString(emulator.lineAtRow(0));
    let row = 1;
    while (true) {
        const line = emulator.lineAtRow(row);
        if (line == null) {
            break;
        }
        result += '\n' + lineToString(line);
        row++;
    }
    return result;
}
class RenderDevice {
    constructor() {
        this.scrollback = [];
        this.screen = [];
    }
    renderEventListener(instance, event) {
        if (event.refreshStartRow !== -1) {
            for (let row = event.refreshStartRow; row < event.refreshEndRow; row++) {
                const line = instance.lineAtRow(row);
                this.screen[row] = lineToString(line);
            }
        }
        if (event.realizedRows < this.screen.length) {
            this.screen = this.screen.slice(0, event.realizedRows);
        }
        event.scrollbackLines.forEach(line => this.scrollback.push(lineToString(line)));
    }
    getScreenString() {
        return this.screen.join('\n');
    }
    getScrollbackString() {
        return this.scrollback.join('\n');
    }
}
function lineToString(line) {
    const lineWithCursor = line.chars.map((c, index) => line.attrs[index] === 0xffffffff ? '#'.codePointAt(0) : c);
    return String.fromCodePoint(...lineWithCursor);
}
function formatRectString(str) {
    const lines = str.split(/\n/g);
    const linesLength = Math.max(...lines.map(lines => lines.length));
    const topBottom = '   +' + '-'.repeat(linesLength) + '+\n';
    const body = lines.map((line, index) => leftPad("" + index, 3) + '|' + line + '|').join('\n');
    return topBottom + body + '\n' + topBottom;
}
function leftPad(str, count) {
    return ' '.repeat(count - str.length) + str;
}
//# sourceMappingURL=TermTest.js.map