"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright 2014-2016 Simon Edwards <simon@simonzone.com>
 *
 * This source code is licensed under the MIT license which is detailed in the LICENSE.txt file.
 */
const MenuItem_1 = require("./MenuItem");
const DomUtils = require("../DomUtils");
const Util = require("./Util");
const ID = "EtCheckboxMenuItemTemplate";
let registered = false;
/**
 * A check box menu item for use inside a context menu.
 */
class CheckboxMenuItem extends MenuItem_1.MenuItem {
    /**
     * Initialize the CheckBoxMenuItem class and resources.
     *
     * When CheckBoxMenuItem is imported into a render process, this static method
     * must be called before an instances may be created. This is can be safely
     * called multiple times.
     */
    static init() {
        if (registered === false) {
            window.customElements.define(CheckboxMenuItem.TAG_NAME.toLowerCase(), CheckboxMenuItem);
            registered = true;
        }
    }
    //-----------------------------------------------------------------------
    //
    //   #                                                         
    //   #       # ###### ######  ####  #   #  ####  #      ###### 
    //   #       # #      #      #    #  # #  #    # #      #      
    //   #       # #####  #####  #        #   #      #      #####  
    //   #       # #      #      #        #   #      #      #      
    //   #       # #      #      #    #   #   #    # #      #      
    //   ####### # #      ######  ####    #    ####  ###### ###### 
    //
    //-----------------------------------------------------------------------
    connectedCallback() {
        super.connectedCallback();
        this._updateChecked(this.getAttribute(CheckboxMenuItem.ATTR_CHECKED));
    }
    static get observedAttributes() {
        return [CheckboxMenuItem.ATTR_CHECKED, MenuItem_1.MenuItem.ATTR_SELECTED];
    }
    /**
     * Custom Element 'attribute changed' hook.
     */
    attributeChangedCallback(attrName, oldValue, newValue) {
        super.attributeChangedCallback(attrName, oldValue, newValue);
        if (attrName === CheckboxMenuItem.ATTR_CHECKED) {
            this._updateChecked(newValue);
        }
    }
    //-----------------------------------------------------------------------
    setChecked(checked) {
        this.setAttribute(CheckboxMenuItem.ATTR_CHECKED, Util.booleanToString(checked));
    }
    getChecked() {
        return Util.htmlValueToBool(this.getAttribute(CheckboxMenuItem.ATTR_CHECKED));
    }
    //-----------------------------------------------------------------------
    _clicked() {
        const checked = this.getAttribute(CheckboxMenuItem.ATTR_CHECKED);
        this.setAttribute(CheckboxMenuItem.ATTR_CHECKED, (!Util.htmlValueToBool(checked)) ? "true" : "false");
    }
    _updateChecked(checked) {
        const shadow = DomUtils.getShadowRoot(this);
        const checkedhtml = "<i class='fa fa-fw fa-" + (Util.htmlValueToBool(checked) ? "check-" : "") + "square-o'></i>";
        shadow.querySelector("#" + MenuItem_1.MenuItem.ID_ICON1).innerHTML = checkedhtml;
    }
}
/**
 * The HTML tag name of this element.
 */
CheckboxMenuItem.TAG_NAME = 'ET-CHECKBOXMENUITEM';
CheckboxMenuItem.ATTR_CHECKED = "checked";
exports.CheckboxMenuItem = CheckboxMenuItem;
//# sourceMappingURL=CheckboxMenuItem.js.map