"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright 2014-2016 Simon Edwards <simon@simonzone.com>
 *
 * This source code is licensed under the MIT license which is detailed in the LICENSE.txt file.
 */
const ContextMenu_1 = require("./ContextMenu");
ContextMenu_1.ContextMenu.init();
const ID = "EtDropDownTemplate";
const SLOT_CONTEXTMENU = "et-contextmenu";
let registered = false;
/**
 * A Drop Down menu.
 *
 * The contents of a DropDown should be a ContextMenu element and another
 * element like a button which emits a click event. When the user activates
 * the button, the ContextMenu is displayed.
 */
class DropDown extends HTMLElement {
    //-----------------------------------------------------------------------
    //
    //   #                                                         
    //   #       # ###### ######  ####  #   #  ####  #      ###### 
    //   #       # #      #      #    #  # #  #    # #      #      
    //   #       # #####  #####  #        #   #      #      #####  
    //   #       # #      #      #        #   #      #      #      
    //   #       # #      #      #    #   #   #    # #      #      
    //   ####### # #      ######  ####    #    ####  ###### ###### 
    //
    //-----------------------------------------------------------------------
    constructor() {
        super();
        const shadow = this.attachShadow({ mode: 'open', delegatesFocus: false });
        const clone = this.createClone();
        shadow.appendChild(clone);
        const clickHandler = (ev) => {
            const cm = this.querySelector(ContextMenu_1.ContextMenu.TAG_NAME);
            cm.openAround(this);
        };
        this._assignSlotContent();
        const len = this.childNodes.length;
        for (let i = 0; i < len; i++) {
            const kid = this.childNodes[i];
            if (kid.nodeName.slice(0, 1) !== '#' && kid.nodeName !== ContextMenu_1.ContextMenu.TAG_NAME) {
                kid.addEventListener('click', clickHandler);
            }
        }
        const cm = this.querySelector(ContextMenu_1.ContextMenu.TAG_NAME);
        cm.addEventListener('selected', (ev) => {
            var event = new CustomEvent('selected', { detail: ev.detail });
            this.dispatchEvent(event);
        });
    }
    /**
     * Initialize the DropDown class and resources.
     *
     * When DropDown is imported into a render process, this static method
     * must be called before an instances may be created. This is can be safely
     * called multiple times.
     */
    static init() {
        if (registered === false) {
            window.customElements.define(DropDown.TAG_NAME.toLowerCase(), DropDown);
            registered = true;
        }
    }
    createClone() {
        let template = window.document.getElementById(ID);
        if (template === null) {
            template = window.document.createElement('template');
            template.id = ID;
            template.innerHTML = `<div><slot name='${SLOT_CONTEXTMENU}'></slot></div><div><slot></slot></div>`;
            window.document.body.appendChild(template);
        }
        return window.document.importNode(template.content, true);
    }
    _assignSlotContent() {
        const len = this.childNodes.length;
        for (let i = 0; i < len; i++) {
            const kid = this.childNodes[i];
            if (kid.nodeName === ContextMenu_1.ContextMenu.TAG_NAME) {
                kid.slot = SLOT_CONTEXTMENU;
            }
        }
    }
}
/**
 * The HTML tag name of this element.
 */
DropDown.TAG_NAME = 'ET-DROPDOWN';
exports.DropDown = DropDown;
//# sourceMappingURL=DropDown.js.map