"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Logger_1 = require("../Logger");
let registered = false;
/**
 * Holds the contents of one tab inside a TabWidget tag.
 */
class Tab extends HTMLElement {
    //-----------------------------------------------------------------------
    //
    //   #                                                         
    //   #       # ###### ######  ####  #   #  ####  #      ###### 
    //   #       # #      #      #    #  # #  #    # #      #      
    //   #       # #####  #####  #        #   #      #      #####  
    //   #       # #      #      #        #   #      #      #      
    //   #       # #      #      #    #   #   #    # #      #      
    //   ####### # #      ######  ####    #    ####  ###### ###### 
    //
    //-----------------------------------------------------------------------
    constructor() {
        super();
        this._initProperties();
        this._mutationObserver = new MutationObserver((mutations) => {
            this._applyDraggable();
        });
        this._mutationObserver.observe(this, { childList: true });
    }
    /**
     * Initialize the Tab class and resources.
     *
     * When Tab is imported into a render process, this static method
     * must be called before an instances may be created. This is can be safely
     * called multiple times.
     */
    static init() {
        if (registered === false) {
            window.customElements.define(Tab.TAG_NAME.toLowerCase(), Tab);
            registered = true;
        }
    }
    _initProperties() {
        this._mutationObserver = null;
        this._log = Logger_1.getLogger(Tab.TAG_NAME, this);
    }
    connectedCallback() {
        this._applyDraggable();
    }
    _applyDraggable() {
        for (const kid of this.childNodes) {
            if (kid instanceof HTMLElement) {
                kid.setAttribute("draggable", "true");
            }
        }
    }
}
/**
 * The HTML tag name of this element.
 */
Tab.TAG_NAME = "ET-TAB";
exports.Tab = Tab;
//# sourceMappingURL=Tab.js.map